==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/outputs/RuleGroupRuleStatementRegexMatchStatementFieldToMatchHeader.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property matchPattern The filter to use to identify the subset of headers to inspect in a web request. The `match_pattern` block supports only one of the following arguments:
 * @property matchScope The parts of the headers to inspect with the rule inspection criteria. If you specify `All`, AWS WAF inspects both keys and values. Valid values include the following: `ALL`, `Key`, `Value`.
 * @property oversizeHandling Oversize handling tells AWS WAF what to do with a web request when the request component that the rule inspects is over the limits. Valid values include the following: `CONTINUE`, `MATCH`, `NO_MATCH`. See the AWS [documentation](https://docs.aws.amazon.com/waf/latest/developerguide/waf-rule-statement-oversize-handling.html) for more information.
 */
public data class RuleGroupRuleStatementRegexMatchStatementFieldToMatchHeader(
    public val matchPattern: RuleGroupRuleStatementRegexMatchStatementFieldToMatchHeaderMatchPattern,
    public val matchScope: String,
    public val oversizeHandling: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.wafv2.outputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchHeader):
            RuleGroupRuleStatementRegexMatchStatementFieldToMatchHeader =
            RuleGroupRuleStatementRegexMatchStatementFieldToMatchHeader(
                matchPattern = javaType.matchPattern().let({ args0 ->
                    com.pulumi.aws.wafv2.kotlin.outputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchHeaderMatchPattern.Companion.toKotlin(args0)
                }),
                matchScope = javaType.matchScope(),
                oversizeHandling = javaType.oversizeHandling(),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/outputs/RuleGroupRuleStatementRegexMatchStatementFieldToMatchHeader.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property matchPattern The filter to use to identify the subset of headers to inspect in a web request. The `match_pattern` block supports only one of the following arguments:
 * @property matchScope The parts of the headers to inspect with the rule inspection criteria. If you specify `All`, AWS WAF inspects both keys and values. Valid values include the following: `ALL`, `Key`, `Value`.
 * @property oversizeHandling Oversize handling tells AWS WAF what to do with a web request when the request component that the rule inspects is over the limits. Valid values include the following: `CONTINUE`, `MATCH`, `NO_MATCH`. See the AWS [documentation](https://docs.aws.amazon.com/waf/latest/developerguide/waf-rule-statement-oversize-handling.html) for more information.
 */
public data class RuleGroupRuleStatementRegexMatchStatementFieldToMatchHeader(
    public val matchPattern: RuleGroupRuleStatementRegexMatchStatementFieldToMatchHeaderMatchPattern,
    public val matchScope: String,
    public val oversizeHandling: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.wafv2.outputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchHeader): RuleGroupRuleStatementRegexMatchStatementFieldToMatchHeader =
            RuleGroupRuleStatementRegexMatchStatementFieldToMatchHeader(
                matchPattern = javaType.matchPattern().let({ args0 ->
                    com.pulumi.aws.wafv2.kotlin.outputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchHeaderMatchPattern.Companion.toKotlin(args0)
                }),
                matchScope = javaType.matchScope(),
                oversizeHandling = javaType.oversizeHandling(),
            )
    }
}
